pygerber.parser.pillow.apertures.polygon module
===============================================

.. automodule:: pygerber.parser.pillow.apertures.polygon
   :members:
   :undoc-members:
   :show-inheritance:
